var system = require("../../../system");
const http = require("http");
const querystring = require('querystring');
var settings = require("../../../../config/settings");
const CtlBase = require("../../ctl.base");
const moment = require('moment');
const appconfig = system.getSysConfig();
class BizOptCtl extends CtlBase {
  constructor() {
    super("bizchance", CtlBase.getServiceName(BizOptCtl));
    this.receiveUrl = "http://192.168.1.140:4011/api/receive/entService/springBoard";
  }

  /*根据用户id获取商机信息，分页获取*/
  async findAndCountAll(pobj, qobj, req) {
    try {
      //TODO 根据业务员id获取该业务员所有列表
      //设置查询条件
      console.log("pobj--",pobj)
      const rs = await this.service.findAndCountAll(pobj);
      let rarr = [];
      let results = rs.results.rows;
      results.forEach(element => {
        let robj = {};
        robj.id = element.id;//数据的id
        robj.demand_code = element.demand_code;//商机编号
        robj.source = element.source_name;//商机来源
        robj.business_type = element.business_type;//商机类型
        robj.business_info_person = element.business_info.contactsName;//联系人
        robj.business_info_phone = element.business_info.contactsPhone;//联系电话
        robj.business_status = element.business_status;//商机当前状态
        robj.updated_at = this.timeFormat(element.updated_at);//商机当前状态日期
        rarr.push(robj);
      });
      rs.results.rows = rarr;
      return system.getResult(rs);
    } catch (error) {
      return system.getResultError(error);
    }
  }

  /*根据商机编号获取商机详情*/
  async findInfoByDemandCode(pobj,qobj,req){
    if (pobj.businessMode && pobj.businessMode != 'undefined')
    {
      try{
        var rs = await this.service.findInfoByDemandCode(pobj);
        var rarr = {}
        if (rs){
          rarr.id =  rs.id;//数据的id
          rarr.businessMode = rs.demand_code;//商机编号
          rarr.channelSource = rs.source_name;//渠道来源
          rarr.businessType = rs.business_type;//商机类型代码
          rarr.businessName = appconfig.pdict.businessType[rarr.businessType];//商机类型名称
          rarr.currentStatus = rs.business_status;//商机状态
          rarr.serviceCode = rs.service_address;//服务地区
          if (rarr.businessName == "园区注册"){
            rarr.serviceName = appconfig.pdict.registeredParkDict[rarr.serviceCode];//服务地区名称
          }
          else{
            rarr.serviceName = appconfig.pdict.registeredAreaDict[rarr.serviceCode];//服务地区名称
          }
          rarr.statusReason = rs.close_reason;//商机关闭原因
          rarr.clerkName = rs.salesman_name;//业务员名称
          rarr.clerkPhone = rs.salesman_phone;//业务员联系方式
          rarr.memoInfo = rs.business_info.memoInfo;//备注信息
          rarr.contactsName = rs.business_info.contactsName;//联系人名称
          rarr.contactsPhone = rs.business_info.contactsPhone;//联系人联系方式
          rarr.servicerCode = rs.facilitator_id;//服务商编码
          rarr.servicerName = rs.facilitator_name;//服务商名称
          rarr.createdTime =  this.timeFormat(rs.created_at);//商机创建时间
          rarr.statusTime =  this.timeFormat(rs.updated_at);//当前状态时间
        }
        return system.getResult(rarr);
      }
      catch(error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误！");
    }
  }

  /*根据商机编号更新商机状态*/
  async updateStatusByDemandCode(pobj,qobj,req){
    if (pobj.businessMode && pobj.businessMode != 'undefined' && pobj.currentStatus && pobj.currentStatus != 'undefined'){
      try{
        var res = await this.service.updateStatusByDemandCode(pobj);
        //调商城接口，回传状态信息，后加
        if (pobj.currentStatus == "isClosed"){
          var rc = system.getObject("util.execClient");
          var requrl = this.receiveUrl;
          var params =  {
            "actionType":"closeNeed",
            "actionBody":{
              "needNum": pobj.businessMode,
              "note":pobj.statusReason
            }
          }   
          var rtn = await rc.execPost(params, requrl);
          var j = JSON.parse(rtn.stdout);
          if (j.status == 1){
            return system.getResult("操作成功！");
          }
          else{
            return system.getResultError("提交方案出错！");
          }
        }
      }
      catch (error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误!");
    }
  }

  /*插入数据信息 */
  async insertInfo(pobj,qobj,req){
    if (pobj.businessMode && pobj.businessMode != 'undefined' && pobj.businessType && pobj.businessType != 'undefined'){
      try{
        await this.service.insertInfo(pobj);
        return system.getResult("插入成功！");

      }
      catch(error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误!");
    }
  }

  timeFormat(date) {
    let localTime = moment.utc(date).toDate();
    localTime = moment(localTime).format("YYYY-MM-DD");
    return localTime;
  }
}
module.exports = BizOptCtl;

// var task = new BizOptCtl();
// var obj={"businessMode":"202006100001","currentStatus":"isClosed","statusReason":"未付款"};
// task.updateStatusByDemandCode(obj,{},{}).then(d=>{
//   console.log(d);
// })
