var system = require("../../../system");
const http = require("http");
const querystring = require('querystring');
var settings = require("../../../../config/settings");
const CtlBase = require("../../ctl.base");
const moment = require('moment');
const appconfig = system.getSysConfig();
class DeliverybillCtl extends CtlBase {
  constructor() {
    super("bizchance", CtlBase.getServiceName(DeliverybillCtl));
    this.materialService = system.getObject("service.bizchance.materialSve");
    this.receiveUrl = "http://192.168.1.140:4011/api/receive/entService/springBoard";
  }

  /*根据用户id获取商机信息，分页获取*/
  async findAndCountAll(pobj, qobj, req) {
    try {
      //TODO 根据业务员id获取该业务员所有交付单列表
      const rs = await this.service.findAndCountAll(pobj);
      let rarr = [];
      let results = rs.results.rows;
      results.forEach(element => {
        let robj = {};
        robj.id = element.id;//数据的id
        robj.deliverNumber = element.delivery_code;//交付单编号
        robj.businessName = element.product_name;//产品名称
        robj.businessType = element.product_code;//产品编码
        robj.sourceName = element.source_name;//渠道来源
        robj.channelNumber = element.source_number;//渠道编码
        robj.baseInfo = element.delivery_info;//交付单详情
        if (robj.businessName == '公司注册'){
          if (robj.baseInfo.isWhether == "是" || robj.baseInfo.isVirtual == "是"){//如果有刻章需求或者是虚拟地址
            robj.relatedProducts = '有';
          }
          else{
            robj.relatedProducts = '无';
          }
        }
        else if (robj.businessName == '云上园区注册'){
          if (robj.baseInfo.isWhether == "是"){//如果有刻章需求或者是虚拟地址
            robj.relatedProducts = '有';
          }
          else{
            robj.relatedProducts = '无';
          }
        }
        else{
          robj.relatedProducts = '无';
        };
        robj.payAmount = element.selling_price;//交付单金额
        robj.deliverStatus = element.delivery_status;//交付单状态
        robj.contactsName = robj.baseInfo.contactsName;//联系人
        robj.contactsPhone = robj.baseInfo.contactsPhone;//联系电话
        robj.createdTime = this.timeFormat(element.created_at);//交付单创建时间
        rarr.push(robj);
      });
      rs.results.rows = rarr;
      return system.getResult(rs);
    } catch (error) {
      return system.getResultError(error);
    }
  }

  /*根据交付单编号获取交付单详情*/
  async findInfoByDeliverCode(pobj,qobj,req){
    if (pobj.deliverNumber && pobj.deliverNumber != 'undefined')
    {
      try{
        var rs = await this.service.findInfoByDeliverCode(pobj);
        var rarr = {}
        if (rs){
          rarr.id =  rs.id;//数据的id
          rarr.deliverNumber = rs.deliver_code;//交付单编号
          rarr.businessName = rs.product_name;//产品名称
          rarr.businessType = rs.product_code;//产品编码
          rarr.channelSource = rs.source_name;//渠道名称
          rarr.channelNumber = rs.source_number;//渠道编码
          //rarr.baseInfo = rs.delivery_info;//交付单详情
          rarr.serviceCode = rs.service_address;//服务地区编码
          if (rarr.businessName == "园区注册"){
            rarr.serviceArea = appconfig.pdict.registeredParkDict[rarr.serviceCode];//服务地区名称
          }
          else{
            rarr.serviceArea = appconfig.pdict.registeredAreaDict[rarr.serviceCode];//服务地区名称
          }
          rarr.contactsName =  rs.delivery_info.contactsName;//联系人姓名
          rarr.contactsPhone = rs.delivery_info.contactsPhone;//联系人电话
          rarr.servicerCode = rs.facilitator_id;//服务商编码
          rarr.servicerName = rs.facilitator_name;//服务商名称
          rarr.clerkName = rs.salesman_name;//业务员名称
          rarr.clerkPhone = rs.salesman_phone;//业务员电话
          rarr.payAmount = rs.selling_price;//交付单金额
          rarr.deliverStatus = rs.delivery_status;//交付单状态
          rarr.statusReason = rs.close_reason;//状态原因
          rarr.createdTime =  this.timeFormat(rs.created_at);//交付单创建时间
          rarr.statusTime =  this.timeFormat(rs.updated_at);//当前状态时间
          //其他详细信息
          var baseInfo = {};
          if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册"){
            baseInfo.isWhether = rs.delivery_info.isWhether;
            if (robj.baseInfo.isWhether == "是"){//如果有刻章需求或者是虚拟地址
              baseInfo.relatedProducts = '有';
            }
            else{
              baseInfo.relatedProducts = '无';
            }
            if (rarr.businessName == "公司注册"){
              baseInfo.isVirtual = rs.delivery_info.isVirtual;
              if (baseInfo.isVirtual == "是"){
                baseInfo.relatedProducts = '有';
              }
            }
            baseInfo.officialSeal = rs.delivery_info.officialSeal;
            baseInfo.businessLicense = rs.delivery_info.businessLicense;
          }

          if (rarr.businessName == "税控申请" || rarr.businessName == "代理记账"){
            baseInfo.taxpayerType = rs.delivery_info.taxpayerType;
            if (rarr.businessName == "代理记账"){
              baseInfo.subjectType = rs.delivery_info.subjectType;
            }
          }

          if (rarr.businessName == "刻章服务"){
            baseInfo.whetherType = rs.delivery_info.whetherType;
          }

          if (rarr.businessName == "注册地址" || rarr.businessName == "代理记账"){
            baseInfo.buyTime = rs.delivery_info.buyTime;
            baseInfo.buyDuration = rs.delivery_info.buyDuration;
            baseInfo.isRenew = rs.delivery_info.isRenew;
          }
          rarr.baseInfo = baseInfo;

          var companyInfo = {};
          var materialInfo = await this.materialService.findInfoByDeliverId(rarr.id);
          if (materialInfo){
            companyInfo.companyName = materialInfo.company_info.companyName;
            companyInfo.fullAddress = materialInfo.company_info.fullAddress;
            companyInfo.operatingPeriod = materialInfo.company_info.operatingPeriod;
            companyInfo.businessScope = materialInfo.company_info.businessScope;
            if (rarr.businessName == "园区注册"){
              companyInfo.individualType = materialInfo.company_info.individualType;
              companyInfo.individualName = appconfig.pdict.registeredTypeDict[companyInfo.individualType];
            }
            if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册"){
              companyInfo.spareName = Arrays.asList(materialInfo.company_info.spareName.split(","));
              companyInfo.taxpayerType = materialInfo.company_info.taxpayerType;
              if (rarr.businessName == "公司注册"){
                companyInfo.companyProperties = materialInfo.company_info.companyProperties;
              }
              companyInfo.addressType = materialInfo.company_info.addressType;
              companyInfo.engagedIndustry = materialInfo.company_info.engagedIndustry;
            }
            if (rarr.businessName != "公司注册" && rarr.businessName != "园区注册" ){
              companyInfo.registeredCapital = materialInfo.company_info.registeredCapital;
              companyInfo.creditCode = materialInfo.company_info.creditCode;
              companyInfo.companyType = materialInfo.company_info.companyType;
              companyInfo.establishedTime = materialInfo.company_info.establishedTime;
              companyInfo.shareholderName = materialInfo.company_info.shareholderName;
            }
            rarr.companyInfo = companyInfo;
            
            if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册"){
              var registeredInfo = {};
              registeredInfo.registeredCapital = materialInfo.registered_info.registeredCapital;
              registeredInfo.reserveProportion = materialInfo.registered_info.reserveProportion;
              if (rarr.businessName == "公司注册" || companyInfo.individualName == "个人独资" ){
                registeredInfo.registeredDate = materialInfo.registered_info.registeredDate;
              }

              rarr.registeredInfo = registeredInfo;
            }

            if (rarr.businessName == "公司注册" || companyInfo.individualName == "个人独资" ){
              var contributionInfo = [];
              var tempList = materialInfo.contribution_info.contributionInfo;//数据格式：{"contributionInfo":[{},{}]}
              tempList.forEach(element => {
                contributionInfo.push(element);
              });
              rarr.contributionInfo = contributionInfo;
            }
            if (rarr.businessName == "公司注册"){
              var positionInfo = [];
              var tempList = materialInfo.position_info.positionInfo;//数据格式：{"positionInfo":[{},{}]}
              tempList.forEach(element => {
                positionInfo.push(element);
              });
              rarr.positionInfo = positionInfo;
            }

            if (companyInfo.individualName == "个体商户")
            {
              rarr.managerInfo = materialInfo.position_info;
            }

            if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册"){
              var regInfo = {};
              if (companyInfo.individualName == "个体商户"){
                regInfo.managerCertificate = materialInfo.file_info.managerCertificate;
              }
              else{
                regInfo.legalpersonCertificate = materialInfo.file_info.legalpersonCertificate;
                regInfo.cfoCertificate = materialInfo.file_info.cfoCertificate;
                if (rarr.businessName == "公司注册"){
                  regInfo.titleCertificate = materialInfo.file_info.titleCertificate;
                  regInfo.naturalpersonCertificate = materialInfo.file_info.naturalpersonCertificate;
                  regInfo.socialCertificate = materialInfo.file_info.socialCertificate;
                  regInfo.directorCertificate = materialInfo.file_info.directorCertificate;
                  regInfo.managerCertificate = materialInfo.file_info.managerCertificate;
                  regInfo.supervisorCertificate = materialInfo.file_info.supervisorCertificate;
                }
              }
              rarr.regInfo = regInfo;
              rarr.expressInfo = materialInfo.express_info;
            }
            

          }
        }
        return system.getResult(rarr);
      }
      catch(error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误！");
    }
  }

  /*根据交付单编号更新交付单状态*/
  async updateInfoByDeliverCode(pobj,qobj,req){
    if (pobj.deliverNumber && pobj.deliverNumber != 'undefined' && pobj.deliverStatus && pobj.deliverStatus != 'undefined'){
      try{
        var res = await this.service.updateInfoByDeliverCode(pobj);
        //调商城接口，回传状态信息，后加

        return system.getResult("更新成功！");
      }
      catch (error){
        return system.getResultError(error);
      }
    }
    else{
      return system.getResultError("参数错误!");
    }
  }

  async insertInfo(pobj,qobj,req){
    if (pobj.businessMode && pobj.businessMode != 'undefined' && pobj.schemeNumber && pobj.schemeNumber != 'undefined'){
      try{
        var res = await this.service.insertInfo(pobj);
        return system.getResult("插入成功！");
      }
      catch (error){
        return system.getResultError(error);
      }
    }else{
      return system.getResultError("参数错误!");
    }
  }

  timeFormat(date) {
    let localTime = moment.utc(date).toDate();
    localTime = moment(localTime).format("YYYY-MM-DD");
    return localTime;
  }
}
module.exports = DeliverybillCtl;

// var task = new DeliverybillCtl();
// var obj={};
// task.updateStatusByDemandCode(obj,{},{}).then(d=>{
//   console.log(d);
//   //console.log(d[0].analyse);

// })
