var system = require("../../../system");
const http = require("http");
const querystring = require('querystring');
var settings = require("../../../../config/settings");
const CtlBase = require("../../ctl.base");
const moment = require('moment');
const appconfig = system.getSysConfig();
class SchemeCtl extends CtlBase {
  constructor() {
    super("bizchance", CtlBase.getServiceName(SchemeCtl));
    this.bizoptService = system.getObject("service.bizchance.bizoptSve");
    this.receiveUrl = "http://192.168.1.140:4011/api/receive/entService/springBoard";
  }

  /*根据id获取方案信息详情*/
  async findById(pobj, qobj, req) {
    if (pobj.id && pobj.id != 'undefined'){
        try{
            var rs = await this.service.findById(pobj);
            var rarr = {}
            if (rs){
                rarr.businessMode = rs.demand_code;//商机编号
                rarr.schemeNumber = rs.scheme_number;//方案编号
                rarr.businessType = "";//商机类型
                rarr.businessName = "";//商机名称
                var bizoptInfo = await this.bizoptService.findInfoByDemandCode({"businessMode":rarr.businessMode});
                if (bizoptInfo){
                    rarr.businessType = bizoptInfo.business_type;
                    rarr.businessName = appconfig.pdict.businessType[rarr.businessType];//商机类型名称
                }
               // rarr.planInfo = rs.scheme_info;//方案详情
                rarr.memoInfo = rs.remark_info;//备注信息
                rarr.currentStatus = rs.scheme_status;//当前状态
                rarr.statusReason = rs.reject_reason;//状态原因
                rarr.businessId = rs.bizopt_id;//商机id
                rarr.servicerCode = rs.facilitator_id;//服务商id
                rarr.servicerName = rs.facilitator_name;//服务商名称
                rarr.clerkName = rs.salesman_name;//业务员名称
                rarr.clerkPhone = rs.salesman_phone;//业务员联系方式
                rarr.createdTime =  this.timeFormat(rs.created_at);//创建方案的日期
                rarr.statusTime = this.timeFormat(rs.updated_at);//当前状态的日期
                var baseInfo = {};
                if (rs.scheme_info.companyName && rs.scheme_info.companyName != 'undefined'){//公司名称
                    rarr.companyName = rs.scheme_info.companyName;
                }
                if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册" 
                    || rarr.businessName == "税控申请" || rarr.businessName == "代理记账"){
                    baseInfo.taxpayerType = rs.scheme_info.taxpayerType;
                }
                if (rarr.businessName == "园区注册"){
                    baseInfo.registeredType = rs.scheme_info.registeredType;
                }
                if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册"){
                    baseInfo.companyProperties  = rs.scheme_info.companyProperties;
                    baseInfo.engagedIndustry = rs.scheme_info.engagedIndustry;
                    baseInfo.addressType = rs.scheme_info.addressType;
                    baseInfo.fullAddress = rs.scheme_info.fullAddress;
                    baseInfo.businessScope = rs.scheme_info.businessScope;
                    baseInfo.isWhether = rs.scheme_info.isWhether;
                }
                if (rarr.businessName == "刻章服务"){
                    baseInfo.whetherType = rs.scheme_info.whetherType;
                }
                if (rarr.businessName == "代理记账"){
                    baseInfo.subjectType = rs.scheme_info.subjectType;
                }
                if (rarr.businessName == "注册地址" || rarr.businessName == "代理记账"){
                    baseInfo.buyTime = rs.scheme_info.buyTime;
                    baseInfo.buyDuration = rs.scheme_info.buyDuration;
                    baseInfo.isRenew = rs.scheme_info.isRenew;
                }
                rarr.baseInfo = baseInfo;
                if (rarr.businessName != "公司注册" && rarr.businessName != "园区注册"){
                    var companyInfo = {};
                    companyInfo.creditCode = rs.scheme_info.creditCode;
                    companyInfo.companyType = rs.scheme_info.companyType;
                    companyInfo.establishedTime = rs.scheme_info.establishedTime;
                    companyInfo.registeredCapital =rs.scheme_info.registeredCapital;
                    companyInfo.shareholderName = rs.scheme_info.shareholderName;
                    companyInfo.businessTerm = rs.scheme_info.businessTerm;
                    companyInfo.businessScope = rs.scheme_info.businessScope;
                    companyInfo.residenceAddress = rs.scheme_info.residenceAddress;
                    rarr.companyInfo = companyInfo;
                }
            }
            return system.getResult(rarr);
        }
        catch(error){
            return system.getResultError(error);
        }
    }
    else{
        return system.getResultError("参数错误！");
    }
  }

  /*根据方案编号获取方案详情*/
  async findInfoBySchemeNumber(pobj, qobj, req){
    if (pobj.schemeNumber && pobj.schemeNumber != 'undefined'){
        try{
            var rs = await this.service.findInfoBySchemeNumber(pobj);
            var rarr = {}
            if (rs){
                rarr.businessMode = rs.demand_code;//商机编号
                rarr.schemeNumber = rs.scheme_number;//方案编号
                rarr.businessType = "";//商机类型
                rarr.businessName = "";//商机名称
                var bizoptInfo = await this.bizoptService.findInfoByDemandCode({"businessMode":rarr.businessMode});
                if (bizoptInfo){
                    rarr.businessType = bizoptInfo.business_type;
                    rarr.businessName = appconfig.pdict.businessType[rarr.businessType];//商机类型名称
                }
                //rarr.planInfo = rs.scheme_info;//方案详情
                rarr.memoInfo = rs.remark_info;//备注信息
                rarr.currentStatus = rs.scheme_status;//当前状态
                rarr.statusReason = rs.reject_reason;//状态原因
                rarr.businessId = rs.bizopt_id;//商机id
                rarr.servicerCode = rs.facilitator_id;//服务商id
                rarr.servicerName = rs.facilitator_name;//服务商名称
                rarr.clerkName = rs.salesman_name;//业务员名称
                rarr.clerkPhone = rs.salesman_phone;//业务员联系方式
                rarr.createdTime =  this.timeFormat(rs.created_at);//创建方案的日期
                rarr.statusTime = this.timeFormat(rs.updated_at);//当前状态的日期
                var baseInfo = {};
                if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册" 
                    || rarr.businessName == "税控申请" || rarr.businessName == "代理记账"){
                    baseInfo.taxpayerType = rs.scheme_info.taxpayerType;
                }
                if (rarr.businessName == "园区注册"){
                    baseInfo.registeredType = rs.scheme_info.registeredType;
                }
                if (rarr.businessName == "公司注册" || rarr.businessName == "园区注册"){
                    if (rarr.businessName == "公司注册"){
                        baseInfo.companyProperties  = rs.scheme_info.companyProperties;
                    }
                    baseInfo.engagedIndustry = rs.scheme_info.engagedIndustry;
                    baseInfo.addressType = rs.scheme_info.addressType;
                    baseInfo.fullAddress = rs.scheme_info.fullAddress;
                    baseInfo.businessScope = rs.scheme_info.businessScope;
                    baseInfo.isWhether = rs.scheme_info.isWhether;
                }
                if (rarr.businessName == "刻章服务"){
                    baseInfo.whetherType = rs.scheme_info.whetherType;
                }
                if (rarr.businessName == "代理记账"){
                    baseInfo.subjectType = rs.scheme_info.subjectType;
                }
                if (rarr.businessName == "注册地址" || rarr.businessName == "代理记账"){
                    baseInfo.buyTime = rs.scheme_info.buyTime;
                    baseInfo.buyDuration = rs.scheme_info.buyDuration;
                    baseInfo.isRenew = rs.scheme_info.isRenew;
                }
                rarr.baseInfo = baseInfo;
                if (rarr.businessName != "公司注册" && rarr.businessName != "园区注册"){
                    var companyInfo = {};
                    companyInfo.creditCode = rs.scheme_info.creditCode;
                    companyInfo.companyType = rs.scheme_info.companyType;
                    companyInfo.establishedTime = rs.scheme_info.establishedTime;
                    companyInfo.registeredCapital =rs.scheme_info.registeredCapital;
                    companyInfo.shareholderName = rs.scheme_info.shareholderName;
                    companyInfo.businessTerm = rs.scheme_info.businessTerm;
                    companyInfo.businessScope = rs.scheme_info.businessScope;
                    companyInfo.residenceAddress = rs.scheme_info.residenceAddress;
                    rarr.companyInfo = companyInfo;
                }
            }
            return system.getResult(rarr);
        }
        catch(error){
            return system.getResultError(error);
        }
    }
    else{
        return system.getResultError("参数错误！");
    }
  }

  /* 根据方案编号更新方案状态及原因 */
  async updateStatusBySchemeNumber(pobj, qobj, req){
    if (pobj.schemeNumber && pobj.schemeNumber != 'undefined' && pobj.currentStatus && pobj.currentStatus != 'undefined'){
        try{
            await this.service.updateStatusBySchemeNumber(pobj);
            return system.getResult("更新成功！");
        }
        catch(error){
            return system.getResultError(error);
        }
    }
    else{
        return system.getResultError("参数错误！");
    }
  }

  /*根据方案编号更新方案详情*/
  async updateInfoBySchemeNumber(pobj, qobj, req){
    if (pobj.schemeNumber && pobj.schemeNumber != 'undefined'){
        try{
            var retn = await this.service.updateInfoBySchemeNumber(pobj);
            if (retn == -1){
                return system.getResultError("要更新的数据不存在！");
            }
            else{
                return system.getResult("更新成功！");
            }       
        }
        catch(error){
            return system.getResultError(error);
        }
    }
    else{
        return system.getResultError("参数错误！");
    }
  }

  /*根据商机编号更新方案编号*/
  async updateSchemeNumberByDemandCode(pobj, qobj, req){
    if (pobj.schemeNumber && pobj.schemeNumber != 'undefined' && pobj.businessMode && pobj.businessMode != 'undefined'){
        try{
            await this.service.updateSchemeNumberByDemandCode(pobj);
            return system.getResult("更新成功！");
        }
        catch(error){
            return system.getResultError(error);
        }
    }
    else{
        return system.getResultError("参数错误！");
    }
  }

  /*插入方案信息*/
  async insertInfo(pobj, qobj, req){
    if (pobj.businessMode && pobj.businessMode != 'undefined' && pobj.currentStatus && pobj.currentStatus != 'undefined' 
        && pobj.baseInfo && pobj.baseInfo != 'undefined'){//商机编号必须存在
        try{
            await this.bizoptService.updateStatusBySchemeNumber(pobj);//修改商机状态
            var businessInfo = await this.bizoptService.findInfoByDemandCode(pobj);//得到商机的信息
            if (businessInfo){
                pobj.businessId = businessInfo.id;//商机id
                pobj.businessType = businessInfo.business_type;//商机类型
                pobj.servicerCode = businessInfo.facilitator_id;//服务商id
                pobj.servicerName = businessInfo.facilitator_name;//服务商的名称
                pobj.clerkOpcode = businessInfo.salesman_opcode;//这个信息需要确认
                pobj.clerkId = businessInfo.salesman_id;//业务员id
                pobj.clerkName = businessInfo.salesman_name;//业务员名称
                pobj.clerkPhone = businessInfo.salesman_phone;//业务员联系电话
                pobj.currentStatus = businessInfo.business_status;//商机状态即为方案状态
                pobj.statusReason = businessInfo.close_reason;//状态原因
            }
            var mobj = pobj;
            mobj.businessType = appconfig.pdict.fdyDict[pobj.businessType];
            var rc = system.getObject("util.execClient");
            var requrl = this.receiveUrl;
            var params =  {
                "actionType":"submitSolution",
                "actionBody":{
                    "needNum": pobj.businessMode,
                    "solutionNum":"",
                    "solutionContent": mobj
                }
            }   
            var rtn = await rc.execPost(params, requrl);
            var j = JSON.parse(rtn.stdout);
            if (j.status == 1){
                pobj.schemeNumber = j.data
                await this.service.insertInfo(pobj);
                return system.getResult("操作成功！");
            }
            else{
                return system.getResultError("提交方案出错！");
            }
            
        }
        catch(error){
            return system.getResultError(error);
        }
    }
    else{
        return system.getResultError("参数错误！");
    }
  }

  timeFormat(date) {
    let localTime = moment.utc(date).toDate();
    localTime = moment(localTime).format("YYYY-MM-DD");
    return localTime;
  }
}
module.exports = SchemeCtl;

var task = new SchemeCtl();
var obj={"businessMode":"202006100011","memoInfo":"sfdsff","whetherType":"individual","creditCode":"1223345455","companyType":"有限公司","companyName":"三个五","establishedTime":"2010-5-6","registeredCapital":"5万元","shareholderName":"2B","businessTerm":"500","businessScope":"sgrgdrgghhh","residenceAddress":"北京市"};
task.insertInfo(obj,{},{}).then(d=>{
  console.log(d);
  //console.log(d[0].analyse);

})
