const system = require("../../../system");
const Dao = require("../../dao.base");
class DeliverybillDao extends Dao {
  constructor() {
    super(Dao.getModelName(DeliverybillDao));
  }

  extraWhere(qobj, qw, qc) {//根据业务员id获取交付单信息的组装条件
    qc.raw = true;
    qc.where.product_code = qc.where.product_code || {
      [this.db.Op.notIn]: ["ICP", "EDI"]
    }
    if(qobj.bizpath && qobj.bizpath!=""){
      if(qobj.bizpath.indexOf("myDeliver")>0){//说明是从商机列表过来的
        qw["salesman_id"]=qobj.userid;
      }
    }

    return qw;
  }

  /*根据交付单编号获取订单详情*/
  async findInfoByDeliverCode(qobj){
    var qcwhere = {"delivery_code":qobj.deliverNumber};
    return await this.findOne(qcwhere);
  }  

  /*根据交付单编号更新状态信息*/
  async updateInfoByDeliverCode(qobj,t){
    var setobj = {"delivery_status":qobj.deliverStatus};
    if (qobj.statusReason && qobj.statusReason != 'undefined'){
      setobj.close_reason = qobj.statusReason;
    }
    var whereobj = {"delivery_code":qobj.deliverNumber};
    return await this.updateByWhere(setobj,whereobj,t);
  }

  /*插入交付单信息*/
  async insertInfo(qobj,t){
    var obj = {
      "demand_code":qobj.businessMode,
      "scheme_number":qobj.schemeNumber
    };
    if (qobj.deliverNumber && qobj.deliverNumber != 'undefined'){
      obj.delivery_code = qobj.deliverNumber;
    }
    if (qobj.businessName && qobj.businessName != 'undefined'){
      obj.product_name = qobj.businessName;
    }
    if (qobj.businessType && qobj.businessType != 'undefined'){
      obj.product_code = qobj.businessType;
    }
    if (qobj.channelSource && qobj.channelSource != 'undefined'){
      obj.source_name = qobj.channelSource;
    }
    if (qobj.channelNumber && qobj.channelNumber != 'undefined'){
      obj.source_number = qobj.channelNumber;
    }
    if (qobj.skuCode && qobj.skuCode != 'undefined'){
      obj.sku_code = qobj.skuCode;
    }
    if (qobj.serviceCode && qobj.serviceCode != 'undefined'){
      obj.service_address = qobj.serviceCode;
    }
    if (qobj.servicerCode && qobj.servicerCode != 'undefined'){
      obj.facilitator_id = qobj.servicerCode;
    }
    if (qobj.servicerName && qobj.servicerName  != 'undefined'){
      obj.facilitator_name = qobj.servicerName;
    }
    if (qobj.clerkName && qobj.clerkName != 'undefined'){
      obj.salesman_name = qobj.clerkName;
    }
    if (qobj.clerkPhone && qobj.clerkPhone != 'undefined'){
      obj.salesman_phone = qobj.clerkPhone
    }
    if (qobj.clerkOpcode && qobj.clerkOpcode != 'undefined'){
      obj.salesman_opcode = qobj.clerkOpcode;
    }
    if (qobj.clerkId && qobj.clerkId != 'undefined'){
      obj.salesman_id = qobj.clerkId;
    }
    if (qobj.payAmount && qobj.payAmount != 'undefined'){
      obj.selling_price = qobj.payAmount;
    }
    if (qobj.deliverStatus && qobj.deliverStatus != 'undefined'){
      obj.delivery_status = qobj.deliverStatus;
    }
    if (qobj.costPrice && qobj.costPrice != 'undefined'){
      obj.cost_price = qobj.costPrice;
    }
    if (qobj.statusReason && qobj.statusReason != 'undefined'){
      obj.close_reason = qobj.statusReason;
    }
    if (qobj.isWhether && qobj.isWhether != 'undefined'){
      obj.delivery_info.isWhether = qobj.isWhether;
    }
    if (qobj.isVirtual && qobj.isVirtual != 'undefined'){
      obj.delivery_info.isVirtual = qobj.isVirtual;
    }
    if (qobj.officialSeal && qobj.officialSeal != 'undefined'){
      obj.delivery_info.officialSeal = qobj.officialSeal;
    }
    if (qobj.businessLicense && qobj.businessLicense != 'undefined'){
      obj.delivery_info.businessLicense = obj.businessLicense;
    }
    if (qobj.taxpayerType && qobj.taxpayerType != 'undefined'){
      obj.delivery_info.taxpayerType = qobj.taxpayerType;
    }
    if (qobj.whetherType && qobj.whetherType != 'undefined'){
      obj.delivery_info.whetherType = qobj.whetherType;
    }
    if (qobj.subjectType && qobj.subjectType != 'undefined'){
      obj.delivery_info.subjectType = qobj.subjectType;
    }
    if (qobj.buyTime && qobj.buyTime != 'undefined'){
      obj.delivery_info.buyTime = qobj.buyTime;
    }
    if (qobj.buyDuration && qobj.buyDuration != 'undefined'){
      obj.delivery_info.buyDuration = qobj.buyDuration;
    }
    if (qobj.isRenew && qobj.isRenew != 'undefined'){
      obj.delivery_info.isRenew = qobj.isRenew;
    }
    if (qobj.contactsName && qobj.contactsName != 'undefined'){
      obj.delivery_info.contactsName = qobj.contactsName;
    }
    if (qobj.contactsPhone && qobj.contactsPhone != 'undefined'){
      obj.delivery_info.contactsPhone = qobj.contactsPhone;
    }
    return await this.create(obj,t);
  }


}
module.exports = DeliverybillDao;
